Changelog
=========

This page documents what's new in each updated version of TurboCtl.

Version 1.1.1
-------------

* Moved TurboCtl documentation to `Read the Docs <https://turboctl.readthedocs.io/en/latest/index.html>`_.
  Previously documentation could be viewed online via https://html-preview.github.io/, but this broke some links.
* Added the :option:`-d` command line argument.


Version 1.1.0
-------------

* Starting TurboCtl now maintains the on/off state of the pump instead of always turning the pump on.
* Made TurboCtl available on PyPI_ and updated the installation instructions.
* Added the :option:`docs` and :option:`reset` commands.
* Made several other small improvements and fixes.

.. _PyPI: https://pypi.org/project/turboctl/
